These base classes are used internally to build PDFs and can also be
used to implement custom PDFs.

They offer more or less support and freedom. The general starting point
should be the ``BasePDF``

.. autosummary::
    :toctree: _generated/custom_base

    zfit.pdf.BasePDF
    zfit.pdf.ZPDF
    zfit.pdf.SimplePDF
    zfit.pdf.SimpleFunctorPDF
    zfit.pdf.WrapDistribution
    zfit.pdf.BaseFunctor
